@@ -59,7 +59,7 @@ ma_generic <- function(es, n, var_e, sample_id = NULL, wt_type = "sample_size",
      call_full <- as.call(append(as.list(call), formal_args))
 
      if(!is.null(data)){
-          data <- data.frame(data)
+          data <- as.data.frame(data)
 
           es <- match_variables(call = call_full[[match("es",  names(call_full))]], arg = es, data = data)
           n <- match_variables(call = call_full[[match("n",  names(call_full))]], arg = n, data = data)
