@@ -19,6 +19,7 @@
      cred_level <- x$cred_level
      cred_method <- x$cred_method
      var_unbiased <- x$var_unbiased
+     decimals <- x$decimals
 
      k <- barebones[,"k"]
      N <- barebones[,"N"]
@@ -27,6 +28,10 @@
      var_e <- barebones[,"var_e"]
      var_res <- barebones[,"var_res"]
      ci_xy_i <- barebones[,grepl(x = colnames(barebones), pattern = "CI")]
+     se_r <- barebones[,"se_r"]
+
+     ad_obj_x <- prepare_ad_int(ad_obj = ad_obj_x, residual_ads = residual_ads, decimals = decimals)
+     ad_obj_y <- prepare_ad_int(ad_obj = ad_obj_y, residual_ads = residual_ads, decimals = decimals)
 
      if(correct_rxx){
           if(indirect_rr_x){
@@ -142,6 +147,7 @@
      var_e <- barebones[,"var_e"]
      var_res <- barebones[,"var_res"]
      ci_xy_i <- barebones[,grepl(x = colnames(barebones), pattern = "CI")]
+     se_r <- barebones[,"se_r"]
 
      var_label <- ifelse(residual_ads, "var_res", "var")
      qxa_label <- ifelse(indirect_rr_x, "qxa_irr", "qxa_drr")
